@@ -21,7 +21,11 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
+
+#include <glib/gi18n-lib.h>
 
 #include <libedata-book/libedata-book.h>
 
@@ -90,6 +94,9 @@ e_book_backend_mapi_gal_factory_init (EBookBackendFactory *factory)
 G_MODULE_EXPORT void
 e_module_load (GTypeModule *type_module)
 {
+	bindtextdomain (GETTEXT_PACKAGE, EXCHANGE_MAPI_LOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+
 	e_source_mapi_folder_type_register (type_module);
 
 	e_book_backend_mapi_contacts_factory_register_type (type_module);
